==> deepin-home_1.6.4.tar.xz: BUILD/translations/deepin-home/pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Zaloguj się za pomocą swojego Deepin ID</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>Zaloguj się, aby kontynuować.</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>Wysyłasz zbyt wiele żądań. Spróbuj ponownie później.</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>Zaloguj się, aby kontynuować.</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>Błąd sieci, spróbuj ponownie później</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>Niezalogowany</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Moje ulubione</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Moje opinie</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Zaloguj</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 wyświetleń</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugestie</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Usuń z ulubionych</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>Cofnij ponaglenie</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Ponaglij</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Wkrótce</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Oficjalna odpowiedź</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Wszystko</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>Bugi</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugestie</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>Sortuj:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>Najnowsze</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Ponaglij</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Komunikacja</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Dołącz do dyskusji</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Zgłoś błąd</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Zgłoś znalezione błędy</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugestie</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Wyślij swoje sugestie</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Zasoby</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Ankieta</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Dołącz do nas</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Testy wewnętrzne</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation>Tłumaczenia globalne</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>Wiadomości społeczności</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>Nie ma więcej przedmiotów</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Wiadomości</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Ankiety</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Uruchom przy starcie systemu</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Główna Deepin</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>Aplikacja do szybkiego logowania się na forum, wysyłania sugestii i zgłaszania błędów.</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Brak wiadomości</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 wiadomości</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Zaznacz wszystkie jako przeczytane</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Zobacz więcej</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Błąd sieci, spróbuj ponownie później</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Odśwież</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Główna Deepin</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Brak ankiet</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Wygasło: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Uzupełnij</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>Oczekiwanie</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Odtwarzanie</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potwierdzono</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Z odpowiedzią</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Rozwiązano</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>W trakcie oceny</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Zaakceptowano</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Zakończono</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>Nie przetworzono problemu i nie pojawi się on na liście publicznej.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>Nie można zidentyfikować przyczyny; wymagana jest dodatkowa analiza.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>Udało się odtworzyć problem i główna przyczyna została znaleziona.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>Problem nie jest bugiem lub jest sprawą innej natury.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>Udało się rozwiązać problem i oczekuje na oficjalne wydanie.</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>Żądanie nie zostało przetworzone i nie pojawi się na liście publicznej.</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>Problem został uznany i oczekuje na wewnętrzną analizę.</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>Zawarto w planie przyszłego wydania</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>Żądanie nie zostało zaakceptowane lub nie można go spełnić</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>Praca deweloperska została zakończona, oczekiwanie na oficjalne wydanie</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>Nie można dodać zrzutu ekranu.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>Rozmiar pliku obrazu nie może przekraczać 1MB.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>Format obrazu nie jest wspierany do załadowania.</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>[Bieżący status produktu]: 
[Oczekiwany produkt]: </translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Warunki wstępne]: 
[Podjęte kroki]: 
[Spodziewany wynik]: 
[Rzeczywisty wynik]: </translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Wyślij opinię</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugestie</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Zgłoszenie błędu</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Tytuł:</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>Podaj krótki opis swojego problemu</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>Zawartość:</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>Nie uwzględniaj wielu problemów w jednym zgłoszeniu</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>Nie uwzględniaj wielu problemów w jednym zgłoszeniu</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>E-mail:</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Wprowadź swój adres e-mail</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Wersja systemu:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Info urządzenia:</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>Załaduj &lt;a href=&apos;home://sysinfo&apos;&gt;informacje urządzenia&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Zrzuty ekranu:</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Pliki obrazów</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>Przeciągnij tutaj lub kliknij przycisk, aby dodać zdjęcia. Maks. trzy</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>Czy na pewno chcesz przerwać wysyłanie opinii?</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>Zawartość opinii nie zostanie zachowana.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Wyślij</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>Nie można wysłać opinii.</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>Wprowadź tytuł i zawartość opinii.</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>Wprowadź tytuł Twojej opinii.</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>Wprowadź zawartość Twojej opinii.</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>Nieprawidłowy adres e-mail.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Informacje urządzenia</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Centrum opinii</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Moje opinie</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Moje ulubione</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>Moje ponaglenia</translation>
    </message>
</context>
</TS>

==> deepin-home_1.6.5.tar.xz: BUILD/translations/deepin-home/pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation>Zaloguj się za pomocą swojego Deepin ID</translation>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation>Zaloguj się, aby kontynuować.</translation>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation>Wysyłasz zbyt wiele żądań. Spróbuj ponownie później.</translation>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation>Zaloguj się, aby kontynuować.</translation>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation>Błąd sieci, spróbuj ponownie później</translation>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>Unlogged</source>
        <translation>Niezalogowany</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Moje ulubione</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Moje opinie</translation>
    </message>
    <message>
        <source>Sign out</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <source>Sign in</source>
        <translation>Zaloguj</translation>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation>%1 wyświetleń</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugestie</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Usuń z ulubionych</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation>Cofnij ponaglenie</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Ponaglij</translation>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Wkrótce</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation>Oficjalna odpowiedź</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Wszystko</translation>
    </message>
    <message>
        <source>Bug</source>
        <translation>Bugi</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugestie</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <source>Sort:</source>
        <translation>Sortuj:</translation>
    </message>
    <message>
        <source>Newest</source>
        <translation>Najnowsze</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Ulubione</translation>
    </message>
    <message>
        <source>Urge</source>
        <translation>Ponaglij</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Komunikacja</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Dołącz do dyskusji</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Zgłoś błąd</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Zgłoś znalezione błędy</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugestie</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Wyślij swoje sugestie</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Zasoby</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Ankieta</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Dołącz do nas</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Testy wewnętrzne</translation>
    </message>
    <message>
        <source>Global Translation</source>
        <translation>Tłumaczenia globalne</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>Wiadomości społeczności</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>No more items</source>
        <translation>Nie ma więcej przedmiotów</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Wiadomości</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Ankiety</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Uruchom przy starcie systemu</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Home</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation>Aplikacja do szybkiego logowania się na forum, wysyłania sugestii i zgłaszania błędów.</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Brak wiadomości</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 wiadomości</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Zaznacz wszystkie jako przeczytane</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Zobacz więcej</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation>Błąd sieci, spróbuj ponownie później</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Odśwież</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Deepin Home</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Brak ankiet</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Wygasło: %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Uzupełnij</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation>Oczekiwanie</translation>
    </message>
    <message>
        <source>Reproducing</source>
        <translation>Odtwarzanie</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Potwierdzono</translation>
    </message>
    <message>
        <source>Replied</source>
        <translation>Z odpowiedzią</translation>
    </message>
    <message>
        <source>Resolved</source>
        <translation>Rozwiązano</translation>
    </message>
    <message>
        <source>Evaluating</source>
        <translation>W trakcie oceny</translation>
    </message>
    <message>
        <source>Accepted</source>
        <translation>Zaakceptowano</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Zakończono</translation>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation>Nie przetworzono problemu i nie pojawi się on na liście publicznej.</translation>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation>Nie można zidentyfikować przyczyny; wymagana jest dodatkowa analiza.</translation>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation>Udało się odtworzyć problem i główna przyczyna została znaleziona.</translation>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation>Problem nie jest bugiem lub jest sprawą innej natury.</translation>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation>Udało się rozwiązać problem i oczekuje na oficjalne wydanie.</translation>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation>Żądanie nie zostało przetworzone i nie pojawi się na liście publicznej.</translation>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation>Problem został uznany i oczekuje na wewnętrzną analizę.</translation>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation>Zawarto w planie przyszłego wydania</translation>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation>Żądanie nie zostało zaakceptowane lub nie można go spełnić</translation>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation>Praca deweloperska została zakończona, oczekiwanie na oficjalne wydanie</translation>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation>Nie można dodać zrzutu ekranu.</translation>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation>Rozmiar pliku obrazu nie może przekraczać 1MB.</translation>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation>Format obrazu nie jest wspierany do załadowania.</translation>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation>[Bieżący status produktu]: 
[Oczekiwany produkt]: </translation>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation>[Warunki wstępne]: 
[Podjęte kroki]: 
[Spodziewany wynik]: 
[Rzeczywisty wynik]: </translation>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation>Wyślij opinię</translation>
    </message>
    <message>
        <source>Type：</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Sugestie</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Zgłoszenie błędu</translation>
    </message>
    <message>
        <source>Title：</source>
        <translation>Tytuł:</translation>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation>Podaj krótki opis swojego problemu</translation>
    </message>
    <message>
        <source>Content：</source>
        <translation>Zawartość:</translation>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation>Nie uwzględniaj wielu problemów w jednym zgłoszeniu</translation>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation>Nie uwzględniaj wielu problemów w jednym zgłoszeniu</translation>
    </message>
    <message>
        <source>Email：</source>
        <translation>E-mail:</translation>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation>Wprowadź swój adres e-mail</translation>
    </message>
    <message>
        <source>System Version:</source>
        <translation>Wersja systemu:</translation>
    </message>
    <message>
        <source>Device Info：</source>
        <translation>Info urządzenia:</translation>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation>Załaduj &lt;a href=&apos;home://sysinfo&apos;&gt;informacje urządzenia&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation>Zrzuty ekranu:</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Pliki obrazów</translation>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation>Przeciągnij tutaj lub kliknij przycisk, aby dodać zdjęcia. Maks. trzy</translation>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation>Czy na pewno chcesz przerwać wysyłanie opinii?</translation>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation>Zawartość opinii nie zostanie zachowana.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <source>Submit</source>
        <translation>Wyślij</translation>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation>Nie można wysłać opinii.</translation>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation>Wprowadź tytuł i zawartość opinii.</translation>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation>Wprowadź tytuł Twojej opinii.</translation>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation>Wprowadź zawartość Twojej opinii.</translation>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation>Nieprawidłowy adres e-mail.</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Informacje urządzenia</translation>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation>Centrum opinii</translation>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation>Moje opinie</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation>Moje ulubione</translation>
    </message>
    <message>
        <source>My Urged</source>
        <translation>Moje ponaglenia</translation>
    </message>
</context>
</TS>
